{ pkgs, config, lib, ... }:
let
  dracula-gtk = pkgs.fetchFromGitHub {
    owner = "dracula";
    repo = "gtk";
    rev = "502f212d83bc67e8f0499574546b99ec6c8e16f9";
    sha256 = "1wx9nzq7cqyvpaq4j60bs8g7gh4jk8qg4016yi4c331l4iw1ymsa";
  };
in
{
  # TODO modularize
  #imports = [ ./xdg.nix ];

  services = {
    gnome.gnome-keyring.enable = true;
    upower.enable = true;

    dbus = {
      enable = true;
      packages = [ pkgs.gnome3.dconf ];
    };
  };

  security.pam.services.sddm.enableGnomeKeyring = true;

  home-manager.users.anish.xdg.enable = true; # This doesn't seem to do anything so we have below
  home-manager.users.anish.xdg.configHome = "/home/anish/.config"; # TODO bad hard coded
  home-manager.users.anish.xdg.configFile = {
    "Kvantum/Dracula/Dracula.kvconfig".source = "${dracula-gtk}/kde/kvantum/Dracula-purple-solid/Dracula-purple-solid.kvconfig";
    "Kvantum/Dracula/Dracula.svg".source = "${dracula-gtk}/kde/kvantum/Dracula-purple-solid/Dracula-purple-solid.svg";
    "Kvantum/kvantum.kvconfig".text = "[General]\ntheme=Dracula";
  };
  environment.sessionVariables = rec {
    XDG_CACHE_HOME = "\${HOME}/.cache";
    XDG_CONFIG_HOME = "\${HOME}/.config";
    XDG_BIN_HOME = "\${HOME}/.local/bin";
    XDG_DATA_HOME = "\${HOME}/.local/share";

    PATH = [
      "\${XDG_BIN_HOME}"
    ];
  };

  nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
    "ripcord"
    "vcv-rack"
  ];

  environment.systemPackages = with pkgs; [
    # TODO move somewhere meaningful
    signal-desktop # bridge to sealight?
    scrot
    ripcord
    feh
    xkblayout-state
    sublime-music
    vcv-rack
    zathura
    calibre
    nheko
    mpv
    scrot
    newsflash
    zeal
    xclip
    xdotool
    rofi
    obs-studio
    lightdm
    dunst
    libnotify
    (polybar.override {
      pulseSupport = true;
      nlSupport = true;
    })
  ];


  location.provider = "geoclue2";
  services = {
    redshift = {
      enable = true;
      temperature = {
        day = 5500;
        night = 3700;
      };
    };
    xserver = {
      enable = true;
      layout = "us,dvorak";
      desktopManager.wallpaper.mode = "fill";
      displayManager = {
        defaultSession = "none+bspwm";
        sessionCommands = ''
          ${pkgs.xorg.xrdb}/bin/xrdb -merge <<EOF
          #define blk  #1F2430
          #define bblk #F28779
          #define red  #A6CC70
          #define bred #FFCC66
          #define grn  #5CCFE6
          #define bgrn #F29E74
          #define ylw  #77A8D9
          #define bylw #5C6773
          #define blu  #707A8C
          #define bblu #F27983
          #define mag  #BAE67E
          #define bmag #FFD580
          #define cyn  #73D0FF
          #define bcyn #FFA759
          #define wht  #95E6CB
          #define bwht #CBCCC6
          #define bg blk
          #define fg wht
          
          *.foreground:  fg
          *.background:  bg
          *.cursorColor: mag
          
          *.color0:  blk
          *.color8:  bblk
          *.color1:  red
          *.color9:  bred
          *.color2:  grn
          *.color10: bgrn
          *.color3:  ylw
          *.color11: bylw
          *.color4:  blu
          *.color12: bblu
          *.color5:  mag
          *.color13: bmag
          *.color6:  cyn
          *.color14: bcyn
          *.color7:  wht
          *.color15: bwht
          
          ! greys
          *.color234: #1E2029
          *.color235: #282a36
          *.color236: #373844
          *.color237: #44475a
          *.color239: #565761
          *.color240: #6272a4
          *.color241: #b6b6b2
          xsetroot -cursor_name left_ptr
          EOF
        '';
        lightdm.enable = true;
        lightdm.greeters.mini.enable = true;
        lightdm.greeters.mini.user = "anish"; # TODO hardcoded
        lightdm.background = "/etc/nixos/users/profiles/desktop/background.jpg";
        lightdm.greeters.mini.extraConfig = ''
          text-color = "#ff79c6"
          password-background-color = "#1E2029"
          window-color = "#181a23"
          border-color = "#181a23"
        '';
      };
      windowManager.bspwm.enable = true;
      #windowManager.bspwm.configFile = "/home/anish/.bspwm/bspwmrc";
      windowManager.bspwm.sxhkd.configFile = "/home/anish/.config/sxhkdrc";
    };
  };

  fonts.fonts = with pkgs; [
    fira-code
    fira-code-symbols
    hermit
    #hack
    siji
    font-awesome-ttf
    proggyfonts
    (nerdfonts.override { fonts = [ "FiraCode" "DroidSansMono" ]; })
  ];

  home-manager.users.anish = {
    # Install themes
    home.packages = with pkgs; [
      ayu-theme-gtk
      dracula-theme
      capitaine-cursors
      paper-icon-theme
      libsForQt5.qtstyleplugin-kvantum
      qt5ct
      gtk-engine-murrine
      gtk_engines
    ];

    xresources.properties = {
      "Xcursor.theme" = "Paper";
      #"Xcursor.size"=  64;
      "*.foreground" = "#95E6CB";
      "*.background" = "#1F2430";
      "*.cursorColor" = "#BAE67E";
      # Black
      "*.color0" = "#1F2430";
      "*.color8" = "#F28779";
      # Red          
      "*.color1" = "#A6CC70";
      "*.color9" = "#FFCC66";
      # Green        
      "*.color2" = "#5CCFE6";
      "*.color10" = "#F29E74";
      # Yellow
      "*.color3" = "#77A8D9";
      "*.color11" = "#5C6773";
      # Blue         
      "*.color4" = "#707A8C";
      "*.color12" = "#F27983";
      # Magenta      
      "*.color5" = "#BAE67E";
      "*.color13" = "#FFD580";
      # Cyan         
      "*.color6" = "#73D0FF";
      "*.color14" = "#FFA759";
      # White        
      "*.color7" = "#95E6CB";
      "*.color15" = "#CBCCC6";
      # Bold, Italic, Underline
      "*.colorBD" = "#e6e1cf";
    };

    # Move required config files around
    home.file = {
      ".config/bspwm/rc.d/polybar".source = ./run.sh;
      ".config/bspwm/bspwmrc".source = ./bspwmrc;
      ".config/sxhkdrc".source = ./sxhkdrc;
      ".config/rofi/theme" = {
        source = ./rofi;
        recursive = true;
      };
      ".config/polybar" = {
        source = ./polybar;
        recursive = true;
      };
      ".config/dunst/dunstrc".source = ./dunstrc;
      ".config/kitty/kitty.conf".source = ./kitty.conf;
      ".config/kitty/ayu.conf".source = ./ayu-kitty.conf;
      ".config/zathura/zathurarc".source = ./zathurarc;
      ".background-image".source = ./background.jpg;
      # gtk3 theme
      ".config/gtk-3.0/settings.ini".text = ''
        [Settings]
        gtk-theme-name=Dracula
        gtk-icon-theme-name=Paper
        gtk-cursor-theme-name=Capitaine Cursors - White
        gtk-fallback-icon-theme=gnome
        gtk-application-prefer-dark-theme=true
        gtk-xft-hinting=1
        gtk-xft-hintstyle=hintfull
        gtk-xft-rgba=none
      '';
      # GTK2 global theme (widget and icon theme)
      ".config/gtk-2.0/gtkrc".text = ''
        gtk-theme-name=Ayu-Mirage
        gtk-icon-theme-name=Capitaine Cursors - White
        gtk-font-name="Sans 10"
      '';
      # TODO hardcoded
      ".local/bin/passmenu".source = ./bin/passmenu;
      ".local/bin/powermenu".source = ./bin/powermenu;
      ".local/bin/screenshot".source = ./bin/screenshot;
    };

    qt = {
      enable = true;
      platformTheme = "gtk";
      style = { name = "qt5ct-style"; };
    };

    # Compositor
    services.picom = {
      enable = true;
      fade = true;
      fadeDelta = 1;
      fadeSteps = [ "0.01" "0.022" ];
      shadow = true;
      shadowOffsets = [ (-10) (-10) ];
      shadowOpacity = "0.22";
      # activeOpacity = "1.00"; 
      # inactiveOpacity = "0.92"; 
      extraOptions = '' 
         shadow-radius = 12;  
         # blur-background = true;  
         # blur-background-frame = true;  
         # blur-background-fixed = true;  
         blur-kern = "7x7box"; 
         blur-strength = 320;  
       '';
    };

    programs.autorandr.enable = true;
    services.udiskie.automount = true;

    services.mpris-proxy.enable = true; # bluetooth media control
  };
}
